@@ -239,10 +239,15 @@ public class K9Helper {
 
             List<Account> accounts = new ArrayList<Account>();
             try {
+                int unnamedCount = 0;
                 while (cursor.moveToNext()) {
                     int accountNumber = cursor.getInt(0);
                     String accountName = cursor.getString(1);
 
+                    if (accountName == null || accountName.length() == 0) {
+                        accountName = "unnamed" + (++unnamedCount);
+                    }
+
                     String accountUuid;
                     int accountColor;
                     if (cursor.getColumnCount() > 2) {
@@ -253,7 +258,7 @@ public class K9Helper {
                         accountColor = 0;
                     }
 
-                    if (accountName != null && accountUuid != null) {
+                    if (accountUuid != null) {
                         accounts.add(new Account(accountNumber, accountName, accountUuid,
                                 accountColor));
                     }
@@ -318,9 +323,8 @@ public class K9Helper {
      */
     public static final Intent getStartK9Intent(Context context) {
         try {
-            Intent intent = new Intent();
             PackageManager manager = context.getPackageManager();
-            intent = manager.getLaunchIntentForPackage(PACKAGE_NAME);
+            Intent intent = manager.getLaunchIntentForPackage(PACKAGE_NAME);
             intent.addCategory(Intent.CATEGORY_LAUNCHER);
             return intent;
         } catch (Exception e) {
@@ -365,4 +369,22 @@ public class K9Helper {
             return false;
         }
     }
+
+    /**
+     * Find out if we have the permission to access K-9 Mail's content provider.
+     *
+     * @param context
+     *         Used to retrieve the package manager.
+     *
+     * @return {@code true} if we have the needed permission, {@code false} otherwise.
+     */
+    public static final boolean hasK9ReadPermission(Context context) {
+        PackageManager manager = context.getPackageManager();
+        try {
+            return (manager.checkPermission(PERMISSION, context.getPackageName()) ==
+                    PackageManager.PERMISSION_GRANTED);
+        } catch (Exception e) {
+            return false;
+        }
+    }
 }
